@@ -103,7 +103,13 @@ char * UIDejunk (char * feed_description) {
 			strsep (&text, "<");
 			strsep (&text, ">");
 		} else
-		 break;
+			break;
+		if (text == NULL) {
+			newtext = malloc (strlen (_("No description available."))+1);
+			strcpy (newtext, _("No description available."));
+			free (start);
+			return newtext;
+		}
 	}
 	newtext = malloc (1);
 	newtext[0] = '\0';
