@@ -132,6 +132,13 @@ int UIChangeFeedName (struct feed *cur_ptr) {
 		return 1;
 	}
 	
+	/* If newname contains "|", abort since this is used as a delimiter for the config file. */
+	if (strstr (newname, "|") != NULL) {
+		free (newname);
+		return 3;
+	}
+	
+	/* Restor original title. */
 	if ((newname != NULL) && (cur_ptr->override != NULL)) {
 		if (strcmp(newname, "-") == 0) {
 			if (cur_ptr->title != NULL)
@@ -357,6 +364,8 @@ int UIDeleteFeed (char * feedname) {
 void UIHelpScreen (void) {
 	int centerx, centery;				/* Screen center x/y coordinate. */
 	int userinput;
+	int offset = 18;
+	int offsetstr = 12;
 	
 	centerx = COLS / 2;
 	centery = LINES / 2;
@@ -364,22 +373,40 @@ void UIHelpScreen (void) {
 	UISupportDrawBox ((COLS/2)-20, (LINES/2)-9, (COLS/2)+24, (LINES/2)+8);
 	
 	attron (WA_REVERSE);
-	mvprintw (centery-8, centerx-18, _("%c:    Add RSS feed..."), keybindings.addfeed);	
-	mvprintw (centery-7, centerx-18, _("%c:    Delete highlighted RSS feed..."), keybindings.deletefeed);
-	mvprintw (centery-6, centerx-18, _("%c:    Rename feed..."), keybindings.changefeedname);
-	mvprintw (centery-5, centerx-18, _("%c:    Reload all feeds"), keybindings.reloadall);
-	mvprintw (centery-4, centerx-18, _("%c:    Reload this feed"), keybindings.reload);
-	mvprintw (centery-3, centerx-18, _("%c:    Mark all read"), keybindings.markread);
-	mvprintw (centery-2, centerx-18, _("%c:    Change default browser..."), keybindings.dfltbrowser);
-	mvprintw (centery-1, centerx-18, _("%c, %c: Move item up, down"), keybindings.moveup, keybindings.movedown);
-	mvprintw (centery,   centerx-18, _("%c:    Sort feed list alphabetically"), keybindings.sortfeeds);
-	mvprintw (centery+1, centerx-18, _("%c:    Categorize feed..."), keybindings.categorize);
-	mvprintw (centery+2, centerx-18, _("%c:    Apply filter..."), keybindings.filter);
-	mvprintw (centery+3, centerx-18, _("%c:    Only current category"), keybindings.filtercurrent);
-	mvprintw (centery+4, centerx-18, _("%c:    Remove filter"), keybindings.nofilter);
-	mvaddstr (centery+5, centerx-18, _("tab:  Type Ahead Find"));
-	mvaddstr (centery+6, centerx-18, _("A:    About"));
-	mvprintw (centery+7, centerx-18, _("%c:    Quit program"), keybindings.quit);
+	/* Keys */
+	mvprintw (centery-8, centerx-offset, "%c:", keybindings.addfeed);	
+	mvprintw (centery-7, centerx-offset, "%c:", keybindings.deletefeed);
+	mvprintw (centery-6, centerx-offset, "%c:", keybindings.changefeedname);
+	mvprintw (centery-5, centerx-offset, "%c:", keybindings.reloadall);
+	mvprintw (centery-4, centerx-offset, "%c:", keybindings.reload);
+	mvprintw (centery-3, centerx-offset, "%c:", keybindings.markread);
+	mvprintw (centery-2, centerx-offset, "%c:", keybindings.dfltbrowser);
+	mvprintw (centery-1, centerx-offset, "%c, %c:", keybindings.moveup, keybindings.movedown);
+	mvprintw (centery,   centerx-offset, "%c:", keybindings.sortfeeds);
+	mvprintw (centery+1, centerx-offset, "%c:", keybindings.categorize);
+	mvprintw (centery+2, centerx-offset, "%c:", keybindings.filter);
+	mvprintw (centery+3, centerx-offset, "%c:", keybindings.filtercurrent);
+	mvprintw (centery+4, centerx-offset, "%c:", keybindings.nofilter);
+	mvaddstr (centery+5, centerx-offset, _("tab:"));
+	mvprintw (centery+6, centerx-offset, "%c:", keybindings.about);
+	mvprintw (centery+7, centerx-offset, "%c:", keybindings.quit);
+	/* Descriptions */
+	mvaddstr (centery-8, centerx-offsetstr, _("Add RSS feed..."));
+	mvaddstr (centery-7, centerx-offsetstr, _("Delete highlighted RSS feed..."));
+	mvaddstr (centery-6, centerx-offsetstr, _("Rename feed..."));
+	mvaddstr (centery-5, centerx-offsetstr, _("Reload all feeds"));
+	mvaddstr (centery-4, centerx-offsetstr, _("Reload this feed"));
+	mvaddstr (centery-3, centerx-offsetstr, _("Mark all read"));
+	mvaddstr (centery-2, centerx-offsetstr, _("Change default browser..."));
+	mvaddstr (centery-1, centerx-offsetstr, _("Move item up, down"));
+	mvaddstr (centery,   centerx-offsetstr, _("Sort feed list alphabetically"));
+	mvaddstr (centery+1, centerx-offsetstr, _("Categorize feed..."));
+	mvaddstr (centery+2, centerx-offsetstr, _("Apply filter..."));
+	mvaddstr (centery+3, centerx-offsetstr, _("Only current category"));
+	mvaddstr (centery+4, centerx-offsetstr, _("Remove filter"));
+	mvaddstr (centery+5, centerx-offsetstr, _("Type Ahead Find"));
+	mvaddstr (centery+6, centerx-offsetstr, _("About"));
+	mvaddstr (centery+7, centerx-offsetstr, _("Quit program"));
 	attroff (WA_REVERSE);
 
 	UIStatus (_("Press the any(tm) key to exit help screen."), 0);
@@ -394,23 +421,37 @@ void UIHelpScreen (void) {
 void UIDisplayFeedHelp (void) {
 	int centerx, centery;				/* Screen center x/y coordinate. */
 	int userinput;
+	int offset = 18;
+	int offsetstr = 7;
 	
 	centerx = COLS / 2;
 	centery = LINES / 2;
 	
-	UISupportDrawBox ((COLS/2)-20, (LINES/2)-5, (COLS/2)+20, (LINES/2)+6);
+	UISupportDrawBox ((COLS/2)-20, (LINES/2)-5, (COLS/2)+24, (LINES/2)+6);
 	
 	attron (WA_REVERSE);
-	mvprintw (centery-4, centerx-18, _("%c, up:    Previous item"), keybindings.prev);	
-	mvprintw (centery-3, centerx-18, _("%c, down:  Next item"), keybindings.next);
-	mvaddstr (centery-2, centerx-18, _("enter:    View item"));
-	mvprintw (centery-1, centerx-18, _("%c:        Reload this feed"), keybindings.reload);
-	mvprintw (centery,   centerx-18, _("%c:        Open homepage"), keybindings.urljump);
-	mvprintw (centery+1, centerx-18, _("%c:        Open link"), keybindings.urljump2);
-	mvprintw (centery+2, centerx-18, _("%c:        Mark all read"), keybindings.markread);
-	mvprintw (centery+3, centerx-18, _("%c:        Show feed info..."), keybindings.feedinfo);
-	mvaddstr (centery+4, centerx-18, _("tab:      Type Ahead Find"));
-	mvprintw (centery+5, centerx-18, _("%c:        Return to main menu"), keybindings.quit);
+	/* Keys */
+	mvprintw (centery-4, centerx-offset, _("%c, up:"), keybindings.prev);	
+	mvprintw (centery-3, centerx-offset, _("%c, down:"), keybindings.next);
+	mvaddstr (centery-2, centerx-offset, _("enter:"));
+	mvprintw (centery-1, centerx-offset, "%c:", keybindings.reload);
+	mvprintw (centery,   centerx-offset, "%c:", keybindings.urljump);
+	mvprintw (centery+1, centerx-offset, "%c:", keybindings.urljump2);
+	mvprintw (centery+2, centerx-offset, "%c:", keybindings.markread);
+	mvprintw (centery+3, centerx-offset, "%c:", keybindings.feedinfo);
+	mvaddstr (centery+4, centerx-offset, _("tab:"));
+	mvprintw (centery+5, centerx-offset, "%c:", keybindings.quit);
+	/* Descriptions */
+	mvprintw (centery-4, centerx-offsetstr, _("Previous item"));	
+	mvprintw (centery-3, centerx-offsetstr, _("Next item"));
+	mvaddstr (centery-2, centerx-offsetstr, _("View item"));
+	mvprintw (centery-1, centerx-offsetstr, _("Reload this feed"));
+	mvprintw (centery,   centerx-offsetstr, _("Open homepage"));
+	mvprintw (centery+1, centerx-offsetstr, _("Open link"));
+	mvprintw (centery+2, centerx-offsetstr, _("Mark all read"));
+	mvprintw (centery+3, centerx-offsetstr, _("Show feed info..."));
+	mvaddstr (centery+4, centerx-offsetstr, _("Type Ahead Find"));
+	mvprintw (centery+5, centerx-offsetstr, _("Return to main menu"));
 	attroff (WA_REVERSE);
 
 	UIStatus (_("Press the any(tm) key to exit help screen."), 0);
@@ -422,6 +463,8 @@ void UIDisplayFeedHelp (void) {
 void UIDisplayItemHelp (void) {
 	int centerx, centery;				/* Screen center x/y coordinate. */
 	int userinput;
+	int offset = 16;
+	int offsetstr = 6;
 	
 	centerx = COLS / 2;
 	centery = LINES / 2;
@@ -429,11 +472,18 @@ void UIDisplayItemHelp (void) {
 	UISupportDrawBox ((COLS/2)-18, (LINES/2)-3, (COLS/2)+18, (LINES/2)+3);
 	
 	attron (WA_REVERSE);
-	mvaddstr (centery-2, centerx-16, _("up, down: Scroll text"));
-	mvprintw (centery-1, centerx-16, _("%c, left:  Previous item"), keybindings.prev);	
-	mvprintw (centery,   centerx-16, _("%c, right: Next item"), keybindings.next);
-	mvprintw (centery+1, centerx-16, _("%c:        Open link"), keybindings.urljump);
-	mvprintw (centery+2, centerx-16, _("%c, enter: Return to overview"), keybindings.quit);
+	/* Keys */
+	mvaddstr (centery-2, centerx-offset, _("cursor:"));
+	mvprintw (centery-1, centerx-offset, "%c, <-:", keybindings.prev);	
+	mvprintw (centery,   centerx-offset, "%c, ->:", keybindings.next);
+	mvprintw (centery+1, centerx-offset, "%c:", keybindings.urljump);
+	mvprintw (centery+2, centerx-offset, _("%c, enter:"), keybindings.quit);
+	/* Descriptions */
+	mvaddstr (centery-2, centerx-offsetstr, _("Scroll text"));
+	mvaddstr (centery-1, centerx-offsetstr, _("Previous item"));	
+	mvaddstr (centery,   centerx-offsetstr, _("Next item"));
+	mvaddstr (centery+1, centerx-offsetstr, _("Open link"));
+	mvaddstr (centery+2, centerx-offsetstr, _("Return to overview"));
 	attroff (WA_REVERSE);
 
 	UIStatus (_("Press the any(tm) key to exit help screen."), 0);
@@ -732,6 +782,7 @@ void UIAbout (void) {
 void CategorizeFeed (struct feed * current_feed) {
 	int i, n, nglobal, y;
 	int uiinput;
+	char tmp[512];
 	char *newcategory;
 	struct feedcategories *category;
 	struct categories *cur_ptr;
@@ -774,8 +825,8 @@ void CategorizeFeed (struct feed * current_feed) {
 				if (i == 58)
 					i += 39;
 			}
-		
-			UIStatus (_("Select category number to add, press 'A' to add a new category or 'q' to quit."), 0);
+			snprintf (tmp, sizeof(tmp), _("Select category number to add, press 'A' to add a new category or '%c' to quit."), keybindings.quit);
+			UIStatus (tmp, 0);
 		} else {
 			i = 49;
 			y = 5;
@@ -788,8 +839,8 @@ void CategorizeFeed (struct feed * current_feed) {
 				if (i == 58)
 					i += 39;
 			}
-	
-			UIStatus (_("Select a category number to delete, press 'A' to add a new one or 'q' to quit."), 0);
+			snprintf (tmp, sizeof(tmp), _("Select a category number to delete, press 'A' to add a new one or '%c' to quit."), keybindings.quit);
+			UIStatus (tmp, 0);
 		}
 		
 		refresh();
