@@ -8,3 +8,6 @@ int UIChangeFeedName (struct feed *cur_ptr);
 int UIAddFeed (void);
 void FeedInfo (struct feed * current_feed);
 int UIDeleteFeed (char * feedname);
+void CategorizeFeed (struct feed * current_feed);
+void CatConf (void);
+char * DialogGetCategoryFilter (void);
