@@ -503,23 +503,24 @@ void UIDisplayFeed (struct feed * current_feed) {
 		/* NULL pointer check! Item may not contain an url at all. */
 		escapetext = NULL;
 		syscallitem = NULL;
-		if (highlighted->link != NULL) {
-			if ((strstr(highlighted->link, "'")) == NULL) {
-				len = strlen(highlighted->link) + 3;
-				escapetext = malloc (len);
-				snprintf (escapetext, len, "\'%s\'", highlighted->link);
-				len = strlen(browser) + len + 1;
-				syscallitem = malloc (len);
-				snprintf (syscallitem, len, browser, escapetext);
-			} else {
-				len = strlen(browser) + 1;
-				syscallitem = malloc (len);
-				snprintf (syscallitem, len, browser, "");
+		if (highlighted != NULL) {
+			if (highlighted->link != NULL) {
+				if ((strstr(highlighted->link, "'")) == NULL) {
+					len = strlen(highlighted->link) + 3;
+					escapetext = malloc (len);
+					snprintf (escapetext, len, "\'%s\'", highlighted->link);
+					len = strlen(browser) + len + 1;
+					syscallitem = malloc (len);
+					snprintf (syscallitem, len, browser, escapetext);
+				} else {
+					//len = strlen(browser) + 1;
+					//syscallitem = malloc (len);
+					//snprintf (syscallitem, len, browser, "");
+					syscallitem = strdup (syscall);
+				}
 			}
 		} else {
-			len = strlen(browser) + 1;
-			syscallitem = malloc (len);
-			snprintf (syscallitem, len, browser, "");
+			syscallitem = strdup (syscall);
 		}
 		
 		UISupportDrawHeader(NULL);
@@ -1235,12 +1236,8 @@ void UIMainInterface (void) {
 				/* Restore original first_ptr if filter is defined! */
 				if (filter != NULL)
 					first_ptr = first_bak;
-#ifdef QUIT_CONFIRM
-				snprintf (tmp, sizeof(tmp), _("Exit Snownews? Press '%c' again to quit."), keybindings.quit);
-				UIStatus (tmp, 0);
-				if (getch() == keybindings.quit)
-#endif
-					MainQuit (NULL, NULL);
+				
+				MainQuit (NULL, NULL);
 			}
 			if (uiinput == keybindings.reload) {
 				if (filter != NULL) {
@@ -1544,6 +1541,9 @@ void UIMainInterface (void) {
 					case 2:
 						UIStatus (_("Original title restored."), 2);
 						break;
+					case 3:
+						UIStatus (_("The new title must not contain a \"|\" character!"), 2);
+						break;
 					default:
 						break;
 				}
