@@ -20,11 +20,4 @@
  *
  */
 
-void InitCurses (void);
-int UIAddFeed (void);
 void UIMainInterface (void);
-void UIStatus (char * text, int delay);
-void UIHelpScreen (void);
-void UIDisplayFeedHelp (void);
-void UIDisplayItemHelp (void);
-void UIAbout (void);
