@@ -604,9 +604,10 @@ int LoadFeed (struct feed * cur_ptr) {
 	fclose (cache);
 	
 	/* After loading DeXMLize the mess. */
-	if ((DeXML (cur_ptr)) != 0)
-		MainQuit (_("Parsing cache"), _("Cache is invalid, please delete directory ~/.snownews/cache/ and try again."));
-	
+	if ((DeXML (cur_ptr)) != 0) {
+		snprintf (tmp, sizeof(tmp), _("Cache for %s is invalid, please delete the file %s and try again."), cur_ptr->feedurl, file);
+		MainQuit (_("Parsing cache"), tmp);
+	}	
 	if (cur_ptr->feed != NULL) {
 		free (cur_ptr->feed);
 		cur_ptr->feed = NULL;
