@@ -380,6 +380,7 @@ char * NetIO (int * my_socket, char * host, char * url, struct feed * cur_ptr, i
 						   after the word "Location:" */
 						strsep (&redirecttarget, " ");
 						
+						/* Location must start with "http", otherwise switch on quirksmode. */
 						if (strncmp(redirecttarget, "http", 4) != 0)
 							quirksmode = 1;
 						
@@ -417,7 +418,18 @@ char * NetIO (int * my_socket, char * host, char * url, struct feed * cur_ptr, i
 						/* The following line \0-terminates tmphost in overwriting the first
 						   / after the hostname. */
 						strsep (&newlocation, "/");
-					
+						
+						/* newlocation must now be the absolute path on newhost.
+						   If not we've been redirected to somewhere totally stupid
+						   (oh yeah, no offsite linking, go to our fucking front page).
+						   Say goodbye to the webserver in this case. In fact, we don't
+						   even say goodbye, but just drop the connection. */
+						if (newlocation == NULL) {
+							UIStatus (_("Webserver sent an invalid redirect!"), 2);
+							fclose (stream);
+							return NULL;
+						}
+						
 						newhost = strdup (tmphost);
 						newlocation--;
 						newlocation[0] = '/';
