@@ -44,8 +44,8 @@
 #include "config.h"
 #include "version.h"
 
-extern char *proxyname;			/* Hostname of proxyserver. */
-extern int proxyport;			/* Port on proxyserver to use. */
+extern char *proxyname;				/* Hostname of proxyserver. */
+extern unsigned short proxyport;	/* Port on proxyserver to use. */
 extern char *useragent;
 
 void AutoVersionCheck (void) {
