@@ -79,10 +79,22 @@ void parse_rdf10_channel(struct feed * feed, xmlDocPtr doc, xmlNodePtr node)
 	for (cur = node; cur != NULL; cur = cur->next) {
 		if (cur->type != XML_ELEMENT_NODE)
 			continue;
-		if (xmlStrcmp(cur->name, "title") == 0)
+		if (xmlStrcmp(cur->name, "title") == 0) {
 			feed->title = xmlNodeListGetString(doc, cur->children, 1);
-		else if (xmlStrcmp(cur->name, "link") == 0)
+			/* Remove trailing newline */
+			if (feed->title != NULL) {
+				if (feed->title[strlen(feed->title)-1] == '\n')
+					feed->title[strlen(feed->title)-1] = '\0';
+			}
+		}
+		else if (xmlStrcmp(cur->name, "link") == 0) {
 			feed->link = xmlNodeListGetString(doc, cur->children, 1);
+			/* Remove trailing newline */
+			if (feed->link != NULL) {
+				if (feed->link[strlen(feed->link)-1] == '\n')
+					feed->link[strlen(feed->link)-1] = '\0';
+			}
+		}
 		else if (xmlStrcmp(cur->name, "description") == 0)
 			feed->description = xmlNodeListGetString(doc, cur->children, 1);
 	}
@@ -131,10 +143,22 @@ void parse_rdf20_channel(struct feed * feed, xmlDocPtr doc, xmlNodePtr node)
 	for (cur = node; cur != NULL; cur = cur->next) {
 		if (cur->type != XML_ELEMENT_NODE)
 			continue;
-		if (xmlStrcmp(cur->name, "title") == 0)
+		if (xmlStrcmp(cur->name, "title") == 0) {
 			feed->title = xmlNodeListGetString(doc, cur->children, 1);
-		else if (xmlStrcmp(cur->name, "link") == 0)
+			/* Remove trailing newline */
+			if (feed->title != NULL) {
+				if (feed->title[strlen(feed->title)-1] == '\n')
+					feed->title[strlen(feed->title)-1] = '\0';
+			}
+		}
+		else if (xmlStrcmp(cur->name, "link") == 0) {
 			feed->link = xmlNodeListGetString(doc, cur->children, 1);
+			/* Remove trailing newline */
+			if (feed->link != NULL) {
+				if (feed->link[strlen(feed->link)-1] == '\n')
+					feed->link[strlen(feed->link)-1] = '\0';
+			}
+		}
 		else if (xmlStrcmp(cur->name, "description") == 0)
 			feed->description = xmlNodeListGetString(doc, cur->children, 1);
 		else if (xmlStrcmp(cur->name, "item") == 0) {
@@ -170,14 +194,25 @@ void parse_rdf10_item(struct feed *feed, xmlDocPtr doc, xmlNodePtr node)
 	for (cur = node; cur != NULL; cur = cur->next) {
 		if (cur->type != XML_ELEMENT_NODE)
 			continue;
-		if (xmlStrcmp(cur->name, "title") == 0)
+		if (xmlStrcmp(cur->name, "title") == 0) {
 			item->title = xmlNodeListGetString(doc, cur->children, 1);
+			/* Remove trailing newline */
+			if (item->title != NULL) {
+				if (item->title[strlen(item->title)-1] == '\n')
+					item->title[strlen(item->title)-1] = '\0';
+			}
+		}
 		else if (xmlStrcmp(cur->name, "link") == 0) {
 			item->link = xmlNodeListGetString(doc, cur->children, 1);
 			if (item->link == NULL) {
 				if (xmlStrcmp(cur->name, "guid") == 0)
 					item->link = xmlNodeListGetString(doc, cur->children, 1);
 			}
+			/* Remove trailing newline */
+			if (item->link != NULL) {
+				if (item->link[strlen(item->link)-1] == '\n')
+					item->link[strlen(item->link)-1] = '\0';
+			}
 		}
 		else if (xmlStrcmp(cur->name, "description") == 0) {
 			item->description = xmlNodeListGetString(doc, cur->children, 1);
